==> biomaj_1.1.0.orig.tar.gz: biomaj_1.1.0/usr/share/biomaj/src/org/inria/biomaj/exe/workflow/VirtualBankWorkflowEngine.java <==
/**
 * Copyright Copr. INRIA/INRA
 * Contact :  biomaj_AT_genouest.org
 * 
 * BioMAJ is a workflow engine dedicated to biological bank management. 
 * The Software automates the update cycle and the supervision of the locally 
 * mirrored bank repository. The project is a collaborative effort between two 
 * French Research Institutes INRIA (Institut National de Recherche en
 * Informatique 
 * et en Automatique) & INRA (Institut National de la Recherche Agronomique).
 *
 * Inter Deposit Digital Number : IDDN ...................................
 *
 * This software is governed by the CeCILL-A license under French law and
 * abiding by the rules of distribution of free software.  You can  use, 
 * modify and/ or redistribute the software under the terms of the CeCILL-B
 * license as circulated by CEA, CNRS and INRIA at the following URL
 * "http://www.cecill.info". 
 *
 * As a counterpart to the access to the source code and  rights to copy,
 * modify and redistribute granted by the license, users are provided only
 * with a limited warranty  and the software's author,  the holder of the
 * economic rights,  and the successive licensors  have only  limited
 * liability. 
 *
 * In this respect, the user's attention is drawn to the risks associated
 * with loading,  using,  modifying and/or developing or reproducing the
 * software by the user in light of its specific status of free software,
 * that may mean  that it is complicated to manipulate,  and  that  also
 * therefore means  that it is reserved for developers  and  experienced
 * professionals having in-depth computer knowledge. Users are therefore
 * encouraged to load and test the software's suitability as regards their
 * requirements in conditions enabling the security of their systems and/or 
 * data to be ensured and,  more generally, to use and operate it in the 
 * same conditions as regards security. 
 * 
 * The fact that you are presently reading this means that you have had
 * knowledge of the CeCILL-A license and that you accept its terms.
 */


package org.inria.biomaj.exe.workflow;

import java.util.Vector;

import org.inria.biomaj.exe.bank.BiomajBank;
import org.inria.biomaj.utils.BiomajException;


public class VirtualBankWorkflowEngine extends BankSetWorkflowEngine {

	public VirtualBankWorkflowEngine(BiomajBank bank) {
		super(bank);
	}

	@Override
	protected void endWorkflow() throws BiomajException {
	super.endWorkflow();
		
	}

	@Override
	protected void initWorkflow() throws BiomajException {
		super.initWorkflow();
	}

	@Override
	protected void runAll() throws BiomajException {
		startTargetFils(WorkflowEngine.TARGET_UNTIL_POSTPROCESS);
		synchronizeFils();
		startTargetFils(WorkflowEngine.TARGET_DEPLOY);
	}

	@Override
	protected void runUntilMirror() throws BiomajException {
		startTargetFils(WorkflowEngine.TARGET_UNTIL_MIRROR);
	}

	@Override
	protected void runUntilMakeProduction() throws BiomajException {
		startTargetFils(WorkflowEngine.TARGET_UNTIL_DEPLOY);
	}

	@Override
	protected void runUntilDeployment() throws BiomajException {
		runAll();
	}

	@Override
	protected void runUntilPostProcess() throws BiomajException {
		startTargetFils(WorkflowEngine.TARGET_UNTIL_POSTPROCESS);
		
	}

	@Override
	protected void runUntilPreProcess() throws BiomajException {
		startTargetFils(WorkflowEngine.TARGET_UNTIL_PREPROCESS);
	}

	@Override
	protected void runDeployment() throws BiomajException {
		startTargetFils(WorkflowEngine.TARGET_DEPLOY);
	}

	@Override
	protected void runMakeProduction() throws BiomajException {
		startTargetFils(WorkflowEngine.TARGET_DEPLOY);
	}

	@Override
	protected void runMirror() throws BiomajException {
		startTargetFils(WorkflowEngine.TARGET_MIRROR);
		
	}

	
	
	@Override
	protected void runRebuild() throws BiomajException {
		startTargetFils(WorkflowEngine.TARGET_REBUILD);
		runAll();
	}

	@Override
	protected void runPostProcess() throws BiomajException {
		startTargetFils(WorkflowEngine.TARGET_POSTPROCESS);
		
	}

	@Override
	protected void runPreProcess() throws BiomajException {
		startTargetFils(WorkflowEngine.TARGET_PREPROCESS);
	}
	
	@Override
	public void runOnlyRemoveProcess() throws BiomajException {
		Vector<String> versions = getVersionToRemove();
		for (String version : versions) {
			runRemoveProcess(version);
		}
	}

	@Override
	public void runRemoveProcess(String version) throws BiomajException {
		startTargetFils(WorkflowEngine.TARGET_REMOVEPROCESS);
		
	}
	

}

==> biomaj_1.2.3.orig.tar.gz: biomaj_1.2.3/usr/share/biomaj/src/org/inria/biomaj/exe/workflow/VirtualBankWorkflowEngine.java <==
/**
 * Copyright Copr. INRIA/INRA
 * Contact :  biomaj_AT_genouest.org
 * 
 * BioMAJ is a workflow engine dedicated to biological bank management. 
 * The Software automates the update cycle and the supervision of the locally 
 * mirrored bank repository. The project is a collaborative effort between two 
 * French Research Institutes INRIA (Institut National de Recherche en
 * Informatique 
 * et en Automatique) & INRA (Institut National de la Recherche Agronomique).
 *
 * Inter Deposit Digital Number : IDDN ...................................
 *
 * This software is governed by the CeCILL-A license under French law and
 * abiding by the rules of distribution of free software.  You can  use, 
 * modify and/ or redistribute the software under the terms of the CeCILL-B
 * license as circulated by CEA, CNRS and INRIA at the following URL
 * "http://www.cecill.info". 
 *
 * As a counterpart to the access to the source code and  rights to copy,
 * modify and redistribute granted by the license, users are provided only
 * with a limited warranty  and the software's author,  the holder of the
 * economic rights,  and the successive licensors  have only  limited
 * liability. 
 *
 * In this respect, the user's attention is drawn to the risks associated
 * with loading,  using,  modifying and/or developing or reproducing the
 * software by the user in light of its specific status of free software,
 * that may mean  that it is complicated to manipulate,  and  that  also
 * therefore means  that it is reserved for developers  and  experienced
 * professionals having in-depth computer knowledge. Users are therefore
 * encouraged to load and test the software's suitability as regards their
 * requirements in conditions enabling the security of their systems and/or 
 * data to be ensured and,  more generally, to use and operate it in the 
 * same conditions as regards security. 
 * 
 * The fact that you are presently reading this means that you have had
 * knowledge of the CeCILL-A license and that you accept its terms.
 */


package org.inria.biomaj.exe.workflow;

import java.util.Vector;

import org.inria.biomaj.exe.bank.BiomajBank;
import org.inria.biomaj.utils.BiomajException;


public class VirtualBankWorkflowEngine extends BankSetWorkflowEngine {

	public VirtualBankWorkflowEngine(BiomajBank bank) {
		super(bank);
	}

	@Override
	protected void endWorkflow() throws BiomajException {
	super.endWorkflow();
		
	}

	@Override
	protected void initWorkflow() throws BiomajException {
		super.initWorkflow();
	}

	@Override
	protected void runAll() throws BiomajException {
		startChildren(WorkflowEngine.TARGET_UNTIL_POSTPROCESS);
		synchronizeChildren();
		startChildren(WorkflowEngine.TARGET_DEPLOY);
	}

	@Override
	protected void runUntilMirror() throws BiomajException {
		startChildren(WorkflowEngine.TARGET_UNTIL_MIRROR);
	}

	@Override
	protected void runUntilMakeProduction() throws BiomajException {
		startChildren(WorkflowEngine.TARGET_UNTIL_DEPLOY);
	}

	@Override
	protected void runUntilDeployment() throws BiomajException {
		runAll();
	}

	@Override
	protected void runUntilPostProcess() throws BiomajException {
		startChildren(WorkflowEngine.TARGET_UNTIL_POSTPROCESS);
		
	}

	@Override
	protected void runUntilPreProcess() throws BiomajException {
		startChildren(WorkflowEngine.TARGET_UNTIL_PREPROCESS);
	}

	@Override
	protected void runDeployment() throws BiomajException {
		startChildren(WorkflowEngine.TARGET_DEPLOY);
	}

	@Override
	protected void runMakeProduction() throws BiomajException {
		startChildren(WorkflowEngine.TARGET_DEPLOY);
	}

	@Override
	protected void runMirror() throws BiomajException {
		startChildren(WorkflowEngine.TARGET_MIRROR);
		
	}

	
	
	@Override
	protected void runRebuild() throws BiomajException {
		startChildren(WorkflowEngine.TARGET_REBUILD);
		runAll();
	}

	@Override
	protected void runPostProcess() throws BiomajException {
		startChildren(WorkflowEngine.TARGET_POSTPROCESS);
		
	}

	@Override
	protected void runPreProcess() throws BiomajException {
		startChildren(WorkflowEngine.TARGET_PREPROCESS);
	}
	
	@Override
	public void runOnlyRemoveProcess() throws BiomajException {
		Vector<String> versions = getVersionToRemove();
		for (String version : versions) {
			runRemoveProcess(version);
		}
	}

	@Override
	public void runRemoveProcess(String version) throws BiomajException {
		startChildren(WorkflowEngine.TARGET_REMOVEPROCESS);
		
	}
	

}
